@@ -39,6 +39,8 @@ DEFAULT_READ_TIMEOUT = 60  # in seconds
 DEFAULT_TIMEOUT = 60  # in seconds
 DEFAULT_GVM_PORT = 9390
 DEFAULT_UNIX_SOCKET_PATH = "/var/run/gvmd.sock"
+DEFAULT_SSH_PORT = 22
+DEFAULT_HOSTNAME = '127.0.0.1'
 MAX_SSH_DATA_LENGTH = 4095
 
 
@@ -185,8 +187,8 @@ class SSHConnection(GvmConnection):
         self,
         *,
         timeout: Optional[int] = DEFAULT_TIMEOUT,
-        hostname: Optional[str] = "127.0.0.1",
-        port: Optional[int] = 22,
+        hostname: Optional[str] = DEFAULT_HOSTNAME,
+        port: Optional[int] = DEFAULT_SSH_PORT,
         username: Optional[str] = "gmp",
         password: Optional[str] = ""
     ):
@@ -275,7 +277,7 @@ class TLSConnection(GvmConnection):
         certfile: Optional[str] = None,
         cafile: Optional[str] = None,
         keyfile: Optional[str] = None,
-        hostname: Optional[str] = "127.0.0.1",
+        hostname: Optional[str] = DEFAULT_HOSTNAME,
         port: Optional[int] = DEFAULT_GVM_PORT,
         password: Optional[str] = None,
         timeout: Optional[int] = DEFAULT_TIMEOUT
